@@ -29,7 +29,7 @@ MPLAYER_OSD_LEVEL = 1
 UI_TIME_FORMAT = "[%X] "
 CONFIG_NAMES = [".syncplay", "syncplay.ini"]  # Syncplay searches first to last
 DEFAULT_CONFIG_NAME = "syncplay.ini"
-RECENT_CLIENT_THRESHOLD = "1.6.8"  # This and higher considered 'recent' clients (no warnings)
+RECENT_CLIENT_THRESHOLD = "1.7.0"  # This and higher considered 'recent' clients (no warnings)
 MUSIC_FORMATS = [".mp3", ".m4a", ".m4p", ".wav", ".aiff", ".r", ".ogg", ".flac"] # ALL LOWER CASE!
 WARN_OLD_CLIENTS = True  # Use MOTD to inform old clients to upgrade
 LIST_RELATIVE_CONFIGS = True  # Print list of relative configs loaded
@@ -96,7 +96,7 @@ DEFAULT_CHAT_FONT_WEIGHT = 1
 
 # Max numbers are used by server (and client pre-connection). Once connected client gets values from server featureList (or uses 'fallback' versions for old servers)
 MAX_CHAT_MESSAGE_LENGTH = 150  # Number of displayed characters
-MAX_USERNAME_LENGTH = 150  # Number of displayed characters
+MAX_USERNAME_LENGTH = 16  # Number of displayed characters
 MAX_ROOM_NAME_LENGTH = 35  # Number of displayed characters
 MAX_FILENAME_LENGTH = 250  # Number of displayed characters
 FALLBACK_MAX_CHAT_MESSAGE_LENGTH = 50  # Number of displayed characters
@@ -125,9 +125,11 @@ COMMANDS_CREATE = ['c', 'create']
 COMMANDS_AUTH = ['a', 'auth']
 COMMANDS_TOGGLE = ['t', 'toggle']
 COMMANDS_QUEUE = ['queue', 'qa', 'add']
+COMMANDS_QUEUEANDSELECT = ['queueandselect','qas']
 COMMANDS_PLAYLIST = ['playlist', 'ql', 'pl']
 COMMANDS_SELECT = ['select', 'qs']
 COMMANDS_DELETE = ['delete', 'd', 'qd']
+COMMANDS_NEXT = ["next", "qn"]
 MPC_MIN_VER = "1.6.4"
 MPC_BE_MIN_VER = "1.5.2.3123"
 VLC_MIN_VERSION = "2.2.1"
@@ -150,24 +152,34 @@ MPC_PATHS = [
     r"c:\program files (x86)\media player classic - home cinema\mpc-hc.exe",
     r"c:\program files (x86)\k-lite codec pack\media player classic\mpc-hc.exe",
     r"c:\program files\k-lite codec pack\media Player classic\mpc-hc.exe",
-    r"C:\program files\k-lite codec pack\mpc-hc64\mpc-hc64.exe",
-    r"C:\program files (x86)\k-lite codec pack\mpc-hc64\mpc-hc64.exe",
+    r"c:\program files\k-lite codec pack\mpc-hc64\mpc-hc64.exe",
+    r"c:\program files (x86)\k-lite codec pack\mpc-hc64\mpc-hc64.exe",
     r"c:\program files (x86)\combined community codec pack\mpc\mpc-hc.exe",
     r"c:\program files\combined community codec pack\mpc\mpc-hc.exe",
     r"c:\program files\mpc homecinema (x64)\mpc-hc64.exe",
+    r"c:\program files (x86)\lav filters\x86\mpc-hc\shoukaku.exe",
+    r"c:\program files (x86)\lav filters\x64\mpc-hc\shoukaku.exe"
 ]
+
+MPC_EXECUTABLES = ["mpc-hc.exe", "mpc-hc64.exe", "mpc-hcportable.exe", "mpc-hc_nvo.exe", "mpc-hc64_nvo.exe", "shoukaku.exe"]
+MPC64_EXECUTABLES = ["mpc-hc64.exe", "mpc-hc64_nvo.exe", "x64\mpc-hc\shoukaku.exe"]
+
 MPC_BE_PATHS = [
-    r"c:\Program Files\MPC-BE x64\mpc-be64.exe",
-    r"c:\Program Files\MPC-BE x64\mpc-be.exe",
-    r"c:\Program Files\MPC-BE\mpc-be64.exe",
-    r"c:\Program Files\MPC-BE\mpc-be.exe"
+    r"c:\program files\mpc-be x64\mpc-be64.exe",
+    r"c:\program files\mpc-be x64\mpc-be.exe",
+    r"c:\program files\mpc-be\mpc-be64.exe",
+    r"c:\program files\mpc-be\mpc-be.exe"
 ]
 MPLAYER_PATHS = ["mplayer2", "mplayer"]
 MPV_PATHS = ["mpv", "/opt/mpv/mpv", r"c:\program files\mpv\mpv.exe", r"c:\program files\mpv-player\mpv.exe",
              r"c:\program Files (x86)\mpv\mpv.exe", r"c:\program Files (x86)\mpv-player\mpv.exe",
              "/Applications/mpv.app/Contents/MacOS/mpv"]
-MPVNET_PATHS = [r"c:\program files\mpv.net\mpvnet.exe", r"c:\program files\mpv.net\mpvnet.exe",
-             r"c:\program Files (x86)\mpv.net\mpvnet.exe", r"c:\program Files (x86)\mpv.net\mpvnet.exe"]
+MPVNET_PATHS = [r"c:\program files\mpv.net\mpvnet.exe", r"c:\program Files (x86)\mpv.net\mpvnet.exe"]
+try:
+    import os
+    MPVNET_PATHS.append(os.path.expandvars(r'%LOCALAPPDATA%\Microsoft\WindowsApps\mpvnet.exe'))
+except:
+    pass
 VLC_PATHS = [
     r"c:\program files (x86)\videolan\vlc\vlc.exe",
     r"c:\program files\videolan\vlc\vlc.exe",
@@ -339,6 +351,11 @@ SYNCPLAY_DOWNLOAD_URL = "https://syncplay.pl/download/"
 SYNCPLAY_PUBLIC_SERVER_LIST_URL = "https://syncplay.pl/listpublicservers?{}"  # Params
 
 DEFAULT_TRUSTED_DOMAINS = ["youtube.com", "youtu.be"]
-TRUSTABLE_WEB_PROTOCOLS = ["http://www.", "https://www.", "http://", "https://"]
+TRUSTABLE_WEB_PROTOCOLS = ["http", "https"]
 
 PRIVATE_FILE_FIELDS = ["path"]
+
+CONSOLE_UI_MODE = "CLI"
+GRAPHICAL_UI_MODE = "GUI"
+UNKNOWN_UI_MODE = "Unknown"
+FALLBACK_ASSUMED_UI_MODE = GRAPHICAL_UI_MODE
