@@ -2,8 +2,21 @@
 
 """English dictionary"""
 
+# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN
+
 en = {
     "LANGUAGE": "English",
+    "LANGUAGE-TAG": "en",
+
+    # Strings for Windows NSIS installer
+    "installer-language-file": "English.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
+    "installer-associate": "Associate Syncplay with multimedia files.",
+    "installer-shortcut": "Create Shortcuts in following locations:",
+    "installer-start-menu": "Start Menu",
+    "installer-desktop": "Desktop",
+    "installer-quick-launch-bar": "Quick Launch Bar",
+    "installer-automatic-updates": "Check for updates automatically",
+    "installer-uninstall-configuration": "Delete configuration file.",
 
     # Client notifications
     "config-cleared-notification": "Settings cleared. Changes will be saved when you store a valid configuration.",
@@ -23,7 +36,7 @@ en = {
     "slowdown-notification": "Slowing down due to time difference with {}",  # User
     "revert-notification": "Reverting speed back to normal",
 
-    "pause-notification": "{} paused",  # User
+    "pause-notification": "{} paused at {}",  # User, Time
     "unpause-notification": "{} unpaused",  # User
     "seek-notification": "{} jumped from {} to {}",  # User, from time, to time
 
@@ -35,7 +48,7 @@ en = {
     "left-notification": "{} has left",  # User
     "left-paused-notification": "{} left, {} paused",  # User who left, User who paused
     "playing-notification": "{} is playing '{}' ({})",  # User, file, duration
-    "playing-notification/room-addendum":  " in room: '{}'",  # Room
+    "playing-notification/room-addendum": " in room: '{}'",  # Room
 
     "not-all-ready": "Not ready: {}",  # Usernames
     "all-users-ready": "Everyone is ready ({} users)",  # Number of ready users
@@ -82,14 +95,17 @@ en = {
     "commandlist-notification/undo": "\tu - undo last seek",
     "commandlist-notification/pause": "\tp - toggle pause",
     "commandlist-notification/seek": "\t[s][+-]time - seek to the given value of time, if + or - is not specified it's absolute time in seconds or min:sec",
+    "commandlist-notification/offset": "\to[+-]duration - offset local playback by the given duration (in seconds or min:sec) from the server seek position - this is a deprecated feature",
     "commandlist-notification/help": "\th - this help",
     "commandlist-notification/toggle": "\tt - toggles whether you are ready to watch or not",
     "commandlist-notification/create": "\tc [name] - create managed room using name of current room",
     "commandlist-notification/auth": "\ta [password] - authenticate as room operator with operator password",
     "commandlist-notification/chat": "\tch [message] - send a chat message in a room",
     "commandList-notification/queue": "\tqa [file/url] - add file or url to bottom of playlist",
+    "commandList-notification/queueandselect": "\tqas [file/url] - add file or url to bottom of playlist and select it",
     "commandList-notification/playlist": "\tql - show the current playlist",
     "commandList-notification/select": "\tqs [index] - select given entry in the playlist",
+    "commandList-notification/next": "\tqn - select next entry in the playlist",
     "commandList-notification/delete": "\tqd [index] - delete the given entry from the playlist",
     "syncplay-version-notification": "Syncplay version: {}",  # syncplay.version
     "more-info-notification": "More info available at: {}",  # projectURL
@@ -163,18 +179,18 @@ en = {
     "argument-description": 'Solution to synchronize playback of multiple media player instances over the network.',
     "argument-epilog": 'If no options supplied _config values will be used',
     "nogui-argument": 'show no GUI',
-    "host-argument": 'server\'s address',
+    "host-argument": "server's address",
     "name-argument": 'desired username',
     "debug-argument": 'debug mode',
     "force-gui-prompt-argument": 'make configuration prompt appear',
-    "no-store-argument": 'don\'t store values in .syncplay',
+    "no-store-argument": "don't store values in .syncplay",
     "room-argument": 'default room',
     "password-argument": 'server password',
     "player-path-argument": 'path to your player executable',
     "file-argument": 'file to play',
     "args-argument": 'player options, if you need to pass options starting with - prepend them with single \'--\' argument',
     "clear-gui-data-argument": 'resets path and window state GUI data stored as QSettings',
-    "language-argument": 'language for Syncplay messages (de/en/ru/it/es/pt_BR/pt_PT/tr)',
+    "language-argument": 'language for Syncplay messages ({})', # Languages
 
     "version-argument": 'prints your version',
     "version-message": "You're using Syncplay version {} ({})",
@@ -290,6 +306,7 @@ en = {
     "autoplay-menu-label": "Show auto-play button",
     "autoplay-guipushbuttonlabel": "Play when all ready",
     "autoplay-minimum-label": "Min users:",
+    "hideemptyrooms-menu-label": "Hide empty persistent rooms",
 
     "sendmessage-label": "Send",
 
@@ -456,6 +473,7 @@ en = {
 
     # Server messages to client
     "new-syncplay-available-motd-message": "You are using Syncplay {} but a newer version is available from https://syncplay.pl",  # ClientVersion
+    "persistent-rooms-notice": "NOTICE: This server uses persistent rooms, which means that the playlist information is stored between playback sessions. If you want to create a room where information is not saved then put -temp at the end of the room name.", # NOTE: Do not translate the word -temp
 
     # Server notifications
     "welcome-server-notification": "Welcome to Syncplay server, ver. {0}",  # version
@@ -473,6 +491,8 @@ en = {
     "server-salt-argument": "random string used to generate managed room passwords",
     "server-disable-ready-argument": "disable readiness feature",
     "server-motd-argument": "path to file from which motd will be fetched",
+    "server-rooms-argument": "path to database file to use and/or create to store persistent room data. Enables rooms to persist without watchers and through restarts",
+    "server-permanent-rooms-argument": "path to file which lists permanent rooms that will be listed even if the room is empty (in the form of a text file which lists one room per line) - requires persistent rooms to be enabled",
     "server-chat-argument": "Should chat be disabled?",
     "server-chat-maxchars-argument": "Maximum number of characters in a chat message (default is {})", # Default number of characters
     "server-maxusernamelength-argument": "Maximum number of characters in a username (default is {})",
