@@ -2,8 +2,21 @@
 
 """Italian dictionary"""
 
+# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN
+
 it = {
     "LANGUAGE": "Italiano",
+    "LANGUAGE-TAG": "it",
+
+    # Strings for Windows NSIS installer
+    "installer-language-file": "Italian.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
+    "installer-associate": "Associa Syncplay con i file multimediali.",
+    "installer-shortcut": "Crea i collegamenti nei percorsi seguenti:",
+    "installer-start-menu": "Menu Start",
+    "installer-desktop": "Desktop",
+    "installer-quick-launch-bar": "Barra di avvio rapido",
+    "installer-automatic-updates": "Controllo automatico degli aggiornamenti",
+    "installer-uninstall-configuration": "Cancella i file di configurazione.",
 
     # Client notifications
     "config-cleared-notification": "Impostazioni iniziali ripristinate. I cambiamenti saranno memorizzati quando salverai una configurazione valida.",
@@ -23,7 +36,7 @@ it = {
     "slowdown-notification": "Rallento a causa della differenza temporale con {}",  # User
     "revert-notification": "Ripristino la velocità di riproduzione normale",
 
-    "pause-notification": "{} ha messo in pausa",  # User
+    "pause-notification": "{} ha messo in pausa ({})",  # User, Time - TODO: Change into format "{} paused at {}" in line with English message
     "unpause-notification": "{} ha ripreso la riproduzione",  # User
     "seek-notification": "{} è passato da {} a {}",  # User, from time, to time
 
@@ -82,14 +95,17 @@ it = {
     "commandlist-notification/undo": "\tu - annulla l'ultima ricerca",
     "commandlist-notification/pause": "\tp - attiva o disattiva la pausa",
     "commandlist-notification/seek": "\t[s][+-]tempo - salta all'istante di tempo dato, se + o - non è specificato si considera il tempo assoluto in secondi o min:sec",
+    "commandlist-notification/offset": "\to[+-]duration - offset local playback by the given duration (in seconds or min:sec) from the server seek position - this is a deprecated feature", # TODO: Translate
     "commandlist-notification/help": "\th - mostra questo help",
     "commandlist-notification/toggle": "\tt - attiva o disattiva la funzionalità \"pronto\"",
     "commandlist-notification/create": "\tc [nome] - crea una stanza gestita usando il nome della stanza attuale",
     "commandlist-notification/auth": "\ta [password] - autentica come gestore della stanza, utilizzando la password del gestore",
     "commandlist-notification/chat": "\tch [message] - invia un messaggio nella chat della stanza",
     "commandList-notification/queue": "\tqa [file/url] - add file or url to bottom of playlist",  # TO DO: Translate
+    "commandList-notification/queueandselect": "\tqas [file/url] - add file or url to bottom of playlist and select it",  # TO DO: Translate
     "commandList-notification/playlist": "\tql - show the current playlist",  # TO DO: Translate
     "commandList-notification/select": "\tqs [index] - select given entry in the playlist",  # TO DO: Translate
+    "commandList-notification/next": "\tqn - select next entry in the playlist", # TODO: Translate
     "commandList-notification/delete": "\tqd [index] - delete the given entry from the playlist",  # TO DO: Translate
     "syncplay-version-notification": "Versione di Syncplay: {}",  # syncplay.version
     "more-info-notification": "Maggiori informazioni a: {}",  # projectURL
@@ -174,7 +190,7 @@ it = {
     "file-argument": 'file da riprodurre',
     "args-argument": 'opzioni del player, se hai bisogno di utilizzare opzioni che iniziano con - anteponi un singolo \'--\'',
     "clear-gui-data-argument": 'ripristina il percorso e i dati impostati tramite interfaccia grafica e salvati come QSettings',
-    "language-argument": 'lingua per i messaggi di Syncplay (de/en/ru/it/es/pt_BR/pt_PT/tr)',
+    "language-argument": 'lingua per i messaggi di Syncplay ({})', # Languages
 
     "version-argument": 'mostra la tua versione',
     "version-message": "Stai usando la versione di Syncplay {} ({})",
@@ -289,6 +305,7 @@ it = {
     "autoplay-menu-label": "Mostra il tasto di riproduzione automatica",
     "autoplay-guipushbuttonlabel": "Riproduci quando tutti sono pronti",
     "autoplay-minimum-label": "Minimo utenti pronti:",
+    "hideemptyrooms-menu-label": "Hide empty persistent rooms", # TODO: Translate
 
     "sendmessage-label": "Invia",
 
@@ -455,6 +472,7 @@ it = {
 
     # Server messages to client
     "new-syncplay-available-motd-message": "Stai usando Syncplay {} ma una nuova versione è disponibile presso https://syncplay.pl",  # ClientVersion
+    "persistent-rooms-notice": "NOTICE: This server uses persistent rooms, which means that the playlist information is stored between playback sessions. If you want to create a room where information is not saved then put -temp at the end of the room name.", # TO DO: Translate - NOTE: Do not translate the word -temp to create a room where information is not saved then put -temp at the end of the room name.", # TO DO: Translate
 
     # Server notifications
     "welcome-server-notification": "Benvenuto nel server Syncplay, ver. {0}",  # version
@@ -472,6 +490,8 @@ it = {
     "server-salt-argument": "usare stringhe casuali per generare le password delle stanze gestite",
     "server-disable-ready-argument": "disabilita la funzionalità \"pronto\"",
     "server-motd-argument": "percorso del file da cui verrà letto il messaggio del giorno",
+    "server-rooms-argument": "path to database file to use and/or create to store persistent room data. Enables rooms to persist without watchers and through restarts", # TODO: Translate
+    "server-permanent-rooms-argument": "path to file which lists permenant rooms that will be listed even if the room is empty (in the form of a text file which lists one room per line) - requires persistent rooms to be enabled", # TODO: Translate
     "server-chat-argument": "abilita o disabilita la chat",
     "server-chat-maxchars-argument": "Numero massimo di caratteri in un messaggio di chat (default è {})", # Default number of characters
     "server-maxusernamelength-argument": "Numero massimo di caratteri in un nome utente (default è {})",
