@@ -2,8 +2,21 @@
 
 """Russian dictionary"""
 
+# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN
+
 ru = {
     "LANGUAGE": "Русский",  # (Russian)
+    "LANGUAGE-TAG": "ru",
+
+    # Strings for Windows NSIS installer
+    "installer-language-file": "Russian.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
+    "installer-associate": "Ассоциировать Syncplay с видеофайлами",
+    "installer-shortcut": "Создать ярлыки:",
+    "installer-start-menu": "в меню Пуск",
+    "installer-desktop": "на рабочем столе",
+    "installer-quick-launch-bar": "в меню быстрого запуска",
+    "installer-automatic-updates": "Проверять обновления автоматически", # TODO: Confirm Russian translation ("Check for updates automatically")
+    "installer-uninstall-configuration": "Удалить файл настроек.",
 
     # Client notifications
     "config-cleared-notification": "Настройки сброшены. Изменения вступят в силу при сохранении корректной конфигурации.",
@@ -23,7 +36,7 @@ ru = {
     "slowdown-notification": "Воспроизведение замедлено из-за разницы во времени с {}",  # User
     "revert-notification": "Возвращаемся к нормальной скорости воспроизведения",
 
-    "pause-notification": "{} приостановил воспроизведение",  # User
+    "pause-notification": "{} приостановил воспроизведение ({})",  # User, Time - TODO: Change into format "{} paused at {}" in line with English message
     "unpause-notification": "{} возобновил воспроизведение",  # User
     "seek-notification": "{} перемотал с {} на {}",  # User, from time, to time
 
@@ -81,14 +94,17 @@ ru = {
     "commandlist-notification/undo": "\tu - отменить последнюю перемотку",
     "commandlist-notification/pause": "\tp - вкл./выкл. паузу",
     "commandlist-notification/seek": "\t[s][+-]time - перемотать к заданному моменту времени, если не указан + или -, то время считается абсолютным (от начала файла) в секундах или мин:сек",
+    "commandlist-notification/offset": "\to[+-]duration - offset local playback by the given duration (in seconds or min:sec) from the server seek position - this is a deprecated feature", # TODO: Translate
     "commandlist-notification/help": "\th - помощь",
     "commandlist-notification/toggle": "\tt - переключить статус готов/не готов к просмотру",
     "commandlist-notification/create": "\tc [имя комнаты] - создать управляемую комнату с таким же именем, как у текущей",
     "commandlist-notification/auth": "\ta [пароль] - авторизоваться как оператор комнаты с помощью пароля",
     "commandlist-notification/chat": "\tch [сообщение] - выслать сообщение в комнату",
     "commandList-notification/queue": "\tqa [файл/URL] - добавить файл или URL в конец списка воспроизведения",
+    "commandList-notification/queueandselect": "\tqas [file/url] - add file or url to bottom of playlist and select it",  # TO DO: Translate
     "commandList-notification/playlist": "\tql - показать текущий список воспроизведения",
     "commandList-notification/select": "\tqs [индекс] - выделить указанный пункт в списке воспроизведения",
+    "commandList-notification/next": "\tqn - выделить следующий пункт в списке воспроизведения",
     "commandList-notification/delete": "\tqd [индекс] - удалить указанный пункт из списка воспроизведения",
     "syncplay-version-notification": "Версия Syncplay: {}",  # syncplay.version
     "more-info-notification": "Больше информации на {}",  # projectURL
@@ -173,7 +189,7 @@ ru = {
     "file-argument": 'воспроизводимый файл',
     "args-argument": 'параметры проигрывателя; если нужно передать параметры, начинающиеся с - , то сначала пишите \'--\'',
     "clear-gui-data-argument": 'сбрасывает путь и данные о состоянии окна GUI, хранимые как QSettings',
-    "language-argument": 'язык сообщений Syncplay (de/en/ru/it/es/pt_BR/pt_PT/tr)',
+    "language-argument": 'язык сообщений Syncplay ({})', # Languages
 
     "version-argument": 'выводит номер версии',
     "version-message": "Вы используете Syncplay версии {} ({})",
@@ -289,11 +305,12 @@ ru = {
     "autoplay-menu-label": "Показывать кнопку &автовоспроизведения",
     "autoplay-guipushbuttonlabel": "Стартовать, когда все будут готовы",
     "autoplay-minimum-label": "Минимум зрителей:",
+    "hideemptyrooms-menu-label": "Скрыть пустые пустоянные комнаты",
     "sendmessage-label": "Выслать",
 
     "ready-guipushbuttonlabel": "Я готов",
 
-    "roomuser-heading-label": "Комната / Зритель",
+    "roomuser-heading-label": "Комната/Зритель",
 
     "size-heading-label": "Размер",
     "duration-heading-label": "Время",
@@ -452,7 +469,8 @@ ru = {
     "nofile-note": "(Никакой файл не проигрывается)",
 
     # Server messages to client
-    "new-syncplay-available-motd-message": "Вы используете Syncplay версии {}. Доступна более новая версия на https://syncplay.pl/",  # ClientVersion
+    "new-syncplay-available-motd-message": "Вы используете Syncplay версии {}. На https://syncplay.pl/ доступна более новая версия.",  # ClientVersion
+    "persistent-rooms-notice": "ВНИМАНИЕ: Этот сервер использует постоянные комнаты, это означает что информация списка воспроизведения сохраняется между сеансами воспроизведения. Если вы хотите создать комнату, в которой информация не сохраняется, поставьте -temp в конце названия комнаты.",
 
     # Server notifications
     "welcome-server-notification": "Добро пожаловать на сервер Syncplay версии {0}",  # version
@@ -467,8 +485,10 @@ ru = {
     "server-password-argument": 'пароль к серверу',
     "server-isolate-room-argument": 'должны ли комнаты быть изолированными?',
     "server-salt-argument": "генерировать пароли к управляемым комнатам на основании указанной строки (соли)",
-    "server-disable-ready-argument": "отключить статусы готов/не готов",
+    "server-disable-ready-argument": "отключить статусы готовности",
     "server-motd-argument": "путь к файлу, из которого будет извлекаться MOTD-сообщение",
+    "server-rooms-argument": "путь к файлу базы данных для использования и/или создания хранилища постоянных данных о комнате. Позволяет комнатам сохраняться без просматривающих, а также после перезапусков",
+    "server-permanent-rooms-argument": "путь к файлу со списком постоянных комнат, которые будут перечислены, даже если комната пуста (в виде текстового файла, в котором указана одна комната на строку) - требуется, чтобы постоянные комнаты были включены",
     "server-chat-argument": "Должен ли чат быть отключён?",
     "server-chat-maxchars-argument": "Максимальное число символов в сообщениях в чате (по умолчанию {})",
     "server-maxusernamelength-argument": "Максимальное число символов в именах пользователей (по умолчанию {})",
