@@ -2,8 +2,21 @@
 
 """Turkish dictionary"""
 
+# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN
+
 tr = {
     "LANGUAGE": "Türkçe", # Turkish
+    "LANGUAGE-TAG": "tr",
+
+    # Strings for Windows NSIS installer
+    "installer-language-file": "Turkish.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
+    "installer-associate": "Syncplay'i ortam dosyalarıyla ilişkilendirin.",
+    "installer-shortcut": "Aşağıdaki konumlarda kısayollar oluşturun:",
+    "installer-start-menu": "Başlangıç menüsü",
+    "installer-desktop": "Masaüstü",
+    "installer-quick-launch-bar": "Hızlı Başlatma Çubuğu",
+    "installer-automatic-updates": "Güncellemeleri otomatik denetle",
+    "installer-uninstall-configuration": "Yapılandırma dosyasını silin.",
 
     # Client notifications
     "config-cleared-notification": "Ayarlar temizlendi. Geçerli bir konfigürasyon kaydettiğinizde değişiklikler kaydedilecektir.",
@@ -23,7 +36,7 @@ tr = {
     "slowdown-notification": "{} ile zaman farkı nedeniyele nedeniyle yavaşlıyor",  # User
     "revert-notification": "Hızı normale döndürülüyor",
 
-    "pause-notification": "{} duraklattı",  # User
+    "pause-notification": "{} duraklattı ({})",  # User, Time - TODO: Change into format "{} paused at {}" in line with English message
     "unpause-notification": "{} devam ettirdi",  # User
     "seek-notification": "{}, {} konumundan {} konumuna atladı",  # User, from time, to time
 
@@ -82,14 +95,17 @@ tr = {
     "commandlist-notification/undo": "\tu - son isteği geri alır",
     "commandlist-notification/pause": "\tp - duraklatmayı değiştirir",
     "commandlist-notification/seek": "\t[s][+-]time - verilen zaman değerine atlar, eğer + veya - belirtilmezse, saniye:dakika cinsinden mutlak zamandır.",
+    "commandlist-notification/offset": "\to[+-]duration - offset local playback by the given duration (in seconds or min:sec) from the server seek position - this is a deprecated feature", # TODO: Translate
     "commandlist-notification/help": "\th - yardım",
     "commandlist-notification/toggle": "\tt - izlemeye hazır olup olmadığınızı değiştirir",
     "commandlist-notification/create": "\tc [name] - mevcut odanın adını kullanarak yönetilen oda oluştur",
     "commandlist-notification/auth": "\ta [password] - operatör şifresi ile oda operatörü olarak kimlik doğrular",
     "commandlist-notification/chat": "\tch [message] - bir odaya sohbet mesajı gönderir",
     "commandList-notification/queue": "\tqa [file/url] - oynatma listesinin altına dosya veya bağlantı ekler",
+    "commandList-notification/queueandselect": "\tqas [file/url] - add file or url to bottom of playlist and select it",  # TO DO: Translate
     "commandList-notification/playlist": "\tql - mevcut oynatma listesini gösterir",
     "commandList-notification/select": "\tqs [index] - oynatma listesinde verilen girişi seçer",
+    "commandList-notification/next": "\tqn - select next entry in the playlist", # TODO: Translate
     "commandList-notification/delete": "\tqd [index] - verilen girişi oynatma listesinden siler",
     "syncplay-version-notification": "Syncplay sürümü: {}",  # syncplay.version
     "more-info-notification": "Daha fazla bilgiye şu adresten ulaşabilirsiniz: {}",  # projectURL
@@ -174,7 +190,7 @@ tr = {
     "file-argument": 'oynatmak için dosya',
     "args-argument": 'oynatıcı seçenekleri, ile başlayan seçenekleri iletmeniz gerekiyorsa - bunların başına tek \'--\' argümanı ekleyin',
     "clear-gui-data-argument": 'QSettings olarak depolanan yol ve pencere durumu GUI verilerini sıfırlar',
-    "language-argument": 'Syncplay mesajları için dil (de/en/ru/it/es/pt_BR/pt_PT/tr)',
+    "language-argument": 'Syncplay mesajları için dil ({})', # Languages
 
     "version-argument": 'versiyonunuzu yazdırır',
     "version-message": "Syncplay sürümünü kullanıyorsunuz {} ({})",
@@ -290,6 +306,7 @@ tr = {
     "autoplay-menu-label": "Otomatik oynat düğmesini göster",
     "autoplay-guipushbuttonlabel": "Her şey hazır olduğunda oynat",
     "autoplay-minimum-label": "Asgari kullanıcı:",
+    "hideemptyrooms-menu-label": "Hide empty persistent rooms", # TODO: Translate
 
     "sendmessage-label": "Gönder",
 
@@ -456,6 +473,7 @@ tr = {
 
     # Server messages to client
     "new-syncplay-available-motd-message": "Syncplay {} kullanıyorsunuz ancak daha yeni bir sürüm https://syncplay.pl adresinde mevcut",  # ClientVersion
+    "persistent-rooms-notice": "NOTICE: This server uses persistent rooms, which means that the playlist information is stored between playback sessions. If you want to create a room where information is not saved then put -temp at the end of the room name.", # TO DO: Translate - NOTE: Do not translate the word -temp
 
     # Server notifications
     "welcome-server-notification": "Syncplay sunucusuna hoş geldiniz, ver. {0}",  # version
@@ -473,6 +491,8 @@ tr = {
     "server-salt-argument": "yönetilen oda şifreleri oluşturmak için kullanılan rastgele dize",
     "server-disable-ready-argument": "hazır olma özelliğini devre dışı bırak",
     "server-motd-argument": "motd alınacak dosyanın yolu",
+    "server-rooms-argument": "path to database file to use and/or create to store persistent room data. Enables rooms to persist without watchers and through restarts", # TODO: Translate
+    "server-permanent-rooms-argument": "path to file which lists permenant rooms that will be listed even if the room is empty (in the form of a text file which lists one room per line) - requires persistent rooms to be enabled", # TODO: Translate
     "server-chat-argument": "Sohbet devre dışı bırakılmalı mı?",
     "server-chat-maxchars-argument": "Bir sohbet mesajındaki maksimum karakter sayısı (varsayılan: {})", # Default number of characters
     "server-maxusernamelength-argument": "Bir kullanıcı adındaki maksimum karakter sayısı (varsayılan {})",
