@@ -9,9 +9,9 @@ from syncplay import utils
 from syncplay.messages import getMessage, getLanguages, setLanguage, getInitialLanguage
 from syncplay.players.playerFactory import PlayerFactory
 from syncplay.utils import isBSD, isLinux, isMacOS, isWindows
-from syncplay.utils import resourcespath, posixresourcespath
+from syncplay.utils import resourcespath, posixresourcespath, playerPathExists
 
-from syncplay.vendor.Qt import QtCore, QtWidgets, QtGui, __binding__, IsPySide, IsPySide2
+from syncplay.vendor.Qt import QtCore, QtWidgets, QtGui, __binding__, IsPySide, IsPySide2, IsPySide6
 from syncplay.vendor.Qt.QtCore import Qt, QSettings, QCoreApplication, QSize, QPoint, QUrl, QLine, QEventLoop, Signal
 from syncplay.vendor.Qt.QtWidgets import QApplication, QLineEdit, QLabel, QCheckBox, QButtonGroup, QRadioButton, QDoubleSpinBox, QPlainTextEdit
 from syncplay.vendor.Qt.QtGui import QCursor, QIcon, QImage, QDesktopServices
@@ -22,7 +22,9 @@ except AttributeError:
     pass  # To ignore error "Attribute Qt::AA_EnableHighDpiScaling must be set before QCoreApplication is created"
 if hasattr(QtCore.Qt, 'AA_UseHighDpiPixmaps'):
     QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)
-if IsPySide2:
+if IsPySide6:
+    from PySide6.QtCore import QStandardPaths
+elif IsPySide2:
     from PySide2.QtCore import QStandardPaths
 
 
@@ -177,6 +179,7 @@ class ConfigDialog(QtWidgets.QDialog):
         RoomsLayout.addWidget(RoomsButtonBox, 2, 0, 1, 1)
         RoomsDialog.setLayout(RoomsLayout)
         RoomsDialog.setModal(True)
+        RoomsDialog.setWindowFlags(RoomsDialog.windowFlags() & ~Qt.WindowContextHelpButtonHint)
         RoomsDialog.show()
         result = RoomsDialog.exec_()
         if result == QtWidgets.QDialog.Accepted:
@@ -209,12 +212,14 @@ class ConfigDialog(QtWidgets.QDialog):
                 self.executablepathCombobox.addItem(foundpath)
 
             else:
-                if not os.path.isfile(playerpath):
+                if not playerPathExists(playerpath):
                     expandedpath = PlayerFactory().getExpandedPlayerPathByPath(playerpath)
-                    if expandedpath is not None and os.path.isfile(expandedpath):
+                    if expandedpath is not None and playerPathExists(expandedpath):
                         playerpath = expandedpath
+                    elif "mpvnet.exe" in playerpath and playerPathExists(playerpath.replace("mpvnet.exe","mpvnet.com")):
+                        self.executablepathCombobox.addItem(playerpath)
 
-                if os.path.isfile(playerpath):
+                if playerPathExists(playerpath):
                     foundpath = playerpath
                     self.executablepathCombobox.addItem(foundpath)
 
@@ -225,7 +230,7 @@ class ConfigDialog(QtWidgets.QDialog):
                 if path != playerpath:
                     self.executablepathCombobox.addItem(path)
 
-            elif os.path.isfile(path) and os.path.normcase(os.path.normpath(path)) != os.path.normcase(os.path.normpath(foundpath)):
+            elif playerPathExists(path) and os.path.normcase(os.path.normpath(path)) != os.path.normcase(os.path.normpath(foundpath)):
                 self.executablepathCombobox.addItem(path)
                 if foundpath == "":
                     foundpath = path
@@ -448,7 +453,7 @@ class ConfigDialog(QtWidgets.QDialog):
                 defaultdirectory = QDesktopServices.storageLocation(QDesktopServices.HomeLocation)
             else:
                 defaultdirectory = ""
-        elif IsPySide2:
+        elif IsPySide6 or IsPySide2:
             if self.config["mediaSearchDirectories"] and os.path.isdir(self.config["mediaSearchDirectories"][0]):
                 defaultdirectory = self.config["mediaSearchDirectories"][0]
             elif os.path.isdir(self.mediadirectory):
@@ -655,6 +660,9 @@ class ConfigDialog(QtWidgets.QDialog):
         self.serverpassLabel = QLabel(getMessage("password-label"), self)
         self.roomsCombobox = QtWidgets.QComboBox(self)
         self.roomsCombobox.setEditable(True)
+        caseSensitiveCompleter = QtWidgets.QCompleter("", self)
+        caseSensitiveCompleter.setCaseSensitivity(Qt.CaseSensitive)
+        self.roomsCombobox.setCompleter(caseSensitiveCompleter)
         self.fillRoomsCombobox()
         self.roomsCombobox.setEditText(config['room'])
         self.usernameLabel = QLabel(getMessage("name-label"), self)
@@ -665,7 +673,6 @@ class ConfigDialog(QtWidgets.QDialog):
         self.editRoomsButton.setIcon(QtGui.QIcon(resourcespath + 'bullet_edit_centered.png'))
         self.editRoomsButton.setObjectName(constants.LOAD_SAVE_MANUALLY_MARKER + "edit-rooms")
         self.editRoomsButton.released.connect(self.openRoomsDialog)
-
         self.hostLabel.setObjectName("host")
         self.hostCombobox.setObjectName(constants.LOAD_SAVE_MANUALLY_MARKER + "host")
         self.usernameLabel.setObjectName("name")
@@ -720,7 +727,10 @@ class ConfigDialog(QtWidgets.QDialog):
         self.executablepathLabel.setObjectName("executable-path")
         self.executablepathCombobox.setObjectName("executable-path")
         self.executablepathCombobox.setMinimumContentsLength(constants.EXECUTABLE_COMBOBOX_MINIMUM_LENGTH)
-        self.executablepathCombobox.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToMinimumContentsLength)
+        if not IsPySide6:
+            self.executablepathCombobox.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToMinimumContentsLength)
+        else:
+            self.executablepathCombobox.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToMinimumContentsLengthWithIcon)
         self.mediapathLabel.setObjectName("media-path")
         self.mediapathTextbox.setObjectName(constants.LOAD_SAVE_MANUALLY_MARKER + "media-path")
         self.playerargsLabel.setObjectName("player-arguments")
