@@ -2,7 +2,7 @@ import os
 
 if "QT_PREFERRED_BINDING" not in os.environ:
     os.environ["QT_PREFERRED_BINDING"] = os.pathsep.join(
-        ["PySide2", "PySide", "PyQt5", "PyQt4"]
+        ["PySide6", "PySide2", "PySide", "PyQt5", "PyQt4"]
     )
 
 try:
